.. Django Kubernetes Manager documentation master file, created by
   sphinx-quickstart on Tue Mar 10 17:28:38 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django Kubernetes Manager's documentation!
=====================================================
Django Kubernetes Manager is an ongoing project to wrap the complexity of Kubernetes management in the simplicity of Django Rest Framework.

Documentation is currently limited and autogenerated. If you are an autodoc wizard please create a PR :)

Quickstart
==========
* Install from PyPi

.. code-block:: bash

  pip install django-kubernetes-manager

* In settings.py (or module) add the app

.. code-block:: python

  INSTALLED_APPS = [
    ... ,
    rest_framework,
    django_kubernetes_manager,
  ]

* In urls.py include the package urls

.. code-block:: python

  urlpatterns = [
    ... ,
    path('dkm/', include('django_kubernetes_manager.urls')),
  ]

* Run migrations and start server

.. code-block:: bash

  ./manage.py migrate
  ./manage.py runserver

* Navigate to django admin and create a TargetCluster

* Sample request

.. code-block:: bash

  curl http://127.0.0.1:8000/dkm/api/namespaces/?format=json

.. code-block:: json

  [
    {
      "title": "veridian-dynamics-aerodynamic-bagels",
      "description": null,
      "cluster": "http://127.0.0.1:8000/dkm/clusters/1/?format=json",
      "config": {},
      "labels": {
        "project": "aerodynamic-bagels",
        "organization": "veridian-dynamics"
      },
      "annotations": {},
      "api_version": "v1",
      "kind": "Namespace",
      "exists": true
    }
  ]

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Modules
==================
`Models`_
----------

`Serializers`_
--------------

`Views`_
-------------

`Utils`_
-------------

.. _Models: django_kubernetes_manager.html#module-django_kubernetes_manager.models.base

.. _Serializers: django_kubernetes_manager.html#module-django_kubernetes_manager.serializers

.. _Views: django_kubernetes_manager.html#module-django_kubernetes_manager.views.model_views

.. _Utils: django_kubernetes_manager.html#module-django_kubernetes_manager.utils
